def about():
    print("This is a simple Python package for geocoding and reverse geocoding.")
    print("It uses the Google Maps API.")
    print("It was created by Galileo Galilei.")
    print("It is distributed under the MIT License.")

def check():
    return True